External Applications
Manage external application integrations for Cortex Cloud.
Retrieves a list of external applications (AWS SQS, AWS S3, Syslog, Splunk, and webhook) and their attributes. The meaning behind all attributes in this response could be found in the ExternalApplication schema. Please note that the field connection_config is retrieved with masked attributes for security purposes; examples are provided in the sample response shown for this endpoint. Please note that the last_modified_by, last_error, and last_error_at attributes are not populated for Syslog integrations.
A list of applications.
Unauthorized access
Unauthorized access due to lack of sufficient permissions
Internal server error. A unified status for API communication type errors.
GET /platform/integration/v1/external-application HTTP/1.1
Host: api-cortex.paloaltonetworks.com
Accept: */*
{
"data": [
{
"application_id": 1,
"name": "Test External Application 01",
"description": "test description for the given external application",
"status": "connected",
"created_at": 1753918286,
"last_modified_by": "john.doe@example.com",
"modified_at": 1753918286,
"application_type": "webhook",
"connection_config": {
"url": "https://webhook.site/305650415-aad3-45ac-9d92-2455105edb96",
"http_method": "POST"
},
"last_error": null,
"last_error_at": null
},
{
"application_id": 2,
"name": "Test External Application 02",
"status": "connected",
"created_at": 1753918288,
"last_modified_by": "john.doe@example.com",
"modified_at": 1753918288,
"application_type": "splunk",
"connection_config": {
"hec_endpoint": "https://splunk-hec-****.company.com:8088/services/collector/event",
"auth_token": "123-****-****-****-abcd456"
},
"last_error": null,
"last_error_at": null
}
]
}Allows the user to create a new external application integration and specify its attributes. To see the possible application_type values, please check the relevant enum in the ExternalApplication schema for additional information. The connection_config attribute is where a user would define AWS SQS, AWS S3, Splunk, Syslog, and webhook configurations; the required formats for these fields are documented in the respective schemas that are linked to the base ConnectionConfig schema. Please ensure that you have setup the proper egress configurations on the Cortex Gateway; this API verifies the new connection against the egress configurations specified for the given tenant. If assistance is required, please utilize the cue on the UI menu for creating a new external application configuration.
Enumerates the parameters for an external application request object
Omitted on insert
Omitted on insert
Must be supplied on insert, but not readOnly.
Omitted on insert
Application successfully created.
Enumerates the various attributes of an external application response object
Bad request for external application create call. Errors here could come from validations of input, egress failures, test connection issues, and more.
Unauthorized access
Unauthorized access due to lack of sufficient permissions
Internal server error. A unified status for API communication type errors.
POST /platform/integration/v1/external-application HTTP/1.1
Host: api-cortex.paloaltonetworks.com
Content-Type: application/json
Accept: */*
Content-Length: 263
{
"request_data": {
"name": "Test External Application 01",
"description": "test description for the given external application",
"application_type": "webhook",
"connection_config": {
"url": "https://webhook.site/305650415-aad3-45ac-9d92-2455105edb96",
"http_method": "POST"
}
}
}{
"data": {
"application_id": "e94fbc98-3053-6506-876b-f809f344f118",
"name": "Test External Application 01",
"description": "test description for the given external application",
"status": "connected",
"created_at": 1753918286,
"last_modified_by": "john.doe@example.com",
"modified_at": 1753918286,
"application_type": "webhook",
"connection_config": {
"url": "https://webhook.site/305650415-aad3-45ac-9d92-2455105edb96",
"http_method": "POST"
},
"last_error": null,
"last_error_at": null
}
}Allows the user to edit an external application and specify its new attributes. To see the possible application_type values, please check the relevant enum in the ExternalApplication schema for additional information. The connection_config attribute is where a user would define AWS SQS, AWS S3, Splunk, Syslog, and webhook configurations; the required formats for these fields are documented in the respective schemas that are linked to the base ConnectionConfig schema. Please ensure that you have setup the proper egress configurations on the Cortex Gateway; this API verifies the new connection against the egress configurations specified for the given tenant. If assistance is required, please utilize the cue on the UI menu for creating a new external application configuration.
The unique identifier of the application.
e94fbc98-3053-6506-876b-f809f344f118Enumerates the parameters for an external application request object
Application updated successfully.
Enumerates the various attributes of an external application response object
Bad request for external application update call. Errors here could come from validations of input, egress failures, test connection issues, and more.
Unauthorized access
Unauthorized access due to lack of sufficient permissions
Internal server error. A unified status for API communication type errors.
PUT /platform/integration/v1/external-application/{application_id} HTTP/1.1
Host: api-cortex.paloaltonetworks.com
Content-Type: application/json
Accept: */*
Content-Length: 263
{
"request_data": {
"name": "Test External Application 03",
"description": "test description for the given external application",
"application_type": "webhook",
"connection_config": {
"url": "https://webhook.site/305650415-aad3-45ac-9d92-2455105edb96",
"http_method": "POST"
}
}
}{
"data": {
"application_id": 2,
"name": "Test External Application 03",
"description": "test description for the given external application",
"status": "connected",
"created_at": 1753918287,
"last_modified_by": "john.doe@example.com",
"modified_at": 1753918288,
"application_type": "webhook",
"connection_config": {
"url": "https://webhook.site/305650415-aad3-45ac-9d92-2455105edb96",
"http_method": "POST"
},
"last_error": null,
"last_error_at": null
}
}Retrieves an external application and returns its attributes. The meaning behind all attributes in this response could be found in the ExternalApplication schema.
The unique identifier of the application.
e94fbc98-3053-6506-876b-f809f344f118The application type of the specified application
webhookPossible values: Application details retrieved successfully.
Enumerates the various attributes of an external application response object
Bad request for external application get by id call
Unauthorized access
Unauthorized access due to lack of sufficient permissions
Internal server error. A unified status for API communication type errors.
GET /platform/integration/v1/external-application/{application_type}/id/{application_id} HTTP/1.1
Host: api-cortex.paloaltonetworks.com
Accept: */*
{
"data": {
"application_id": "e94fbc98-3053-6506-876b-f809f344f118",
"name": "Test External Application 01",
"description": "test description for the given external application",
"status": "connected",
"created_at": 1753918286,
"last_modified_by": "john.doe@example.com",
"modified_at": 1753918286,
"application_type": "webhook",
"connection_config": {
"url": "https://webhook.site/305650415-aad3-45ac-9d92-2455105edb96",
"http_method": "POST"
},
"last_error": null,
"last_error_at": null
}
}Allows the user to delete an external application. Deletion is not permitted if the application is associated with an active notification rule.
The unique identifier of the application.
e94fbc98-3053-6506-876b-f809f344f118The application type of the specified application
syslogPossible values: Successful deletion of External Application
Bad request for external application delete call
Unauthorized access
Unauthorized access due to lack of sufficient permissions
Internal server error. A unified status for API communication type errors.
DELETE /platform/integration/v1/external-application/{application_type}/id/{application_id} HTTP/1.1
Host: api-cortex.paloaltonetworks.com
Accept: */*
No content
Last updated
Was this helpful?
